@@ -1,6 +1,6 @@
 package Tapper::MCP::Net::TAP;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::Net::TAP::VERSION = '5.0.6';
+$Tapper::MCP::Net::TAP::VERSION = '5.0.7';
 use 5.010;
 use strict;
 use warnings;
@@ -140,8 +140,8 @@ sub upload_files
                 chomp $file;
                 my $reportfile=$file;
                 $reportfile =~ s|^$path||;
-                $reportfile =~ s|^./||;
-                $reportfile =~ s|[^A-Za-z0-9_-]|_|g;
+                #$reportfile =~ s|^./||;
+                #$reportfile =~ s|[^A-Za-z0-9_-]|_|g;
                 my $cmdline =  "#! upload $reportid ";
                 $cmdline   .=  $reportfile;
                 $cmdline   .=  " plain\n";
@@ -251,7 +251,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2018 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
